==> microsoft.bingads-13.0.17-sources.jar: com/microsoft/bingads/v13/adinsight/ArrayOfPerformanceInsightsMessage.java <==

package com.microsoft.bingads.v13.adinsight;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ArrayOfPerformanceInsightsMessage complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ArrayOfPerformanceInsightsMessage">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="PerformanceInsightsMessage" type="{https://bingads.microsoft.com/AdInsight/v13}PerformanceInsightsMessage" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ArrayOfPerformanceInsightsMessage", propOrder = {
    "performanceInsightsMessages"
})
public class ArrayOfPerformanceInsightsMessage {

    @XmlElement(name = "PerformanceInsightsMessage", nillable = true)
    protected List<PerformanceInsightsMessage> performanceInsightsMessages;

    /**
     * Gets the value of the performanceInsightsMessages property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the performanceInsightsMessages property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPerformanceInsightsMessages().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PerformanceInsightsMessage }
     * 
     * 
     * @return
     *     The value of the performanceInsightsMessages property.
     */
    public List<PerformanceInsightsMessage> getPerformanceInsightsMessages() {
        if (performanceInsightsMessages == null) {
            performanceInsightsMessages = new ArrayList<>();
        }
        return this.performanceInsightsMessages;
    }

}

==> microsoft.bingads-13.0.23-sources.jar: com/microsoft/bingads/v13/adinsight/ArrayOfPerformanceInsightsMessage.java <==

package com.microsoft.bingads.v13.adinsight;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonCreator;

/**
 * <p>Java class for ArrayOfPerformanceInsightsMessage complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ArrayOfPerformanceInsightsMessage">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="PerformanceInsightsMessage" type="{https://bingads.microsoft.com/AdInsight/v13}PerformanceInsightsMessage" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ArrayOfPerformanceInsightsMessage", propOrder = {
    "performanceInsightsMessages"
})
public class ArrayOfPerformanceInsightsMessage {

    @XmlElement(name = "PerformanceInsightsMessage", nillable = true)
    protected List<PerformanceInsightsMessage> performanceInsightsMessages;
    public ArrayOfPerformanceInsightsMessage()
    {
      this.performanceInsightsMessages = new ArrayList<PerformanceInsightsMessage>();
    }
    @JsonCreator
    public ArrayOfPerformanceInsightsMessage(List<PerformanceInsightsMessage> performanceinsightsmessages)
    {
      this.performanceInsightsMessages = performanceinsightsmessages;
    }

    /**
     * Gets the value of the performanceInsightsMessages property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the performanceInsightsMessages property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPerformanceInsightsMessages().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PerformanceInsightsMessage }
     * 
     * 
     * @return
     *     The value of the performanceInsightsMessages property.
     */
    public List<PerformanceInsightsMessage> getPerformanceInsightsMessages() {
        if (performanceInsightsMessages == null) {
            performanceInsightsMessages = new ArrayList<>();
        }
        return this.performanceInsightsMessages;
    }

}
